"""
Type annotations for mailmanager service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_mailmanager.type_defs import AddHeaderActionTypeDef

    data: AddHeaderActionTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from collections.abc import Mapping, Sequence
from datetime import datetime
from typing import Any, Union

from .literals import (
    AcceptActionType,
    ActionFailurePolicyType,
    ArchiveBooleanOperatorType,
    ArchiveStateType,
    ArchiveStringEmailAttributeType,
    ExportStateType,
    ImportDataTypeType,
    ImportJobStatusType,
    IngressBooleanOperatorType,
    IngressIpOperatorType,
    IngressPointStatusToUpdateType,
    IngressPointStatusType,
    IngressPointTypeType,
    IngressStringOperatorType,
    IngressTlsProtocolAttributeType,
    IngressTlsProtocolOperatorType,
    IpTypeType,
    MailFromType,
    RetentionPeriodType,
    RuleAddressListEmailAttributeType,
    RuleBooleanEmailAttributeType,
    RuleBooleanOperatorType,
    RuleDmarcOperatorType,
    RuleDmarcPolicyType,
    RuleIpOperatorType,
    RuleNumberOperatorType,
    RuleStringEmailAttributeType,
    RuleStringOperatorType,
    RuleVerdictAttributeType,
    RuleVerdictOperatorType,
    RuleVerdictType,
    SearchStateType,
    SnsNotificationEncodingType,
    SnsNotificationPayloadTypeType,
)

if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "AddHeaderActionTypeDef",
    "AddonInstanceTypeDef",
    "AddonSubscriptionTypeDef",
    "AddressFilterTypeDef",
    "AddressListTypeDef",
    "AnalysisTypeDef",
    "ArchiveActionTypeDef",
    "ArchiveBooleanExpressionTypeDef",
    "ArchiveBooleanToEvaluateTypeDef",
    "ArchiveFilterConditionOutputTypeDef",
    "ArchiveFilterConditionTypeDef",
    "ArchiveFiltersOutputTypeDef",
    "ArchiveFiltersTypeDef",
    "ArchiveFiltersUnionTypeDef",
    "ArchiveRetentionTypeDef",
    "ArchiveStringExpressionOutputTypeDef",
    "ArchiveStringExpressionTypeDef",
    "ArchiveStringToEvaluateTypeDef",
    "ArchiveTypeDef",
    "CreateAddonInstanceRequestTypeDef",
    "CreateAddonInstanceResponseTypeDef",
    "CreateAddonSubscriptionRequestTypeDef",
    "CreateAddonSubscriptionResponseTypeDef",
    "CreateAddressListImportJobRequestTypeDef",
    "CreateAddressListImportJobResponseTypeDef",
    "CreateAddressListRequestTypeDef",
    "CreateAddressListResponseTypeDef",
    "CreateArchiveRequestTypeDef",
    "CreateArchiveResponseTypeDef",
    "CreateIngressPointRequestTypeDef",
    "CreateIngressPointResponseTypeDef",
    "CreateRelayRequestTypeDef",
    "CreateRelayResponseTypeDef",
    "CreateRuleSetRequestTypeDef",
    "CreateRuleSetResponseTypeDef",
    "CreateTrafficPolicyRequestTypeDef",
    "CreateTrafficPolicyResponseTypeDef",
    "DeleteAddonInstanceRequestTypeDef",
    "DeleteAddonSubscriptionRequestTypeDef",
    "DeleteAddressListRequestTypeDef",
    "DeleteArchiveRequestTypeDef",
    "DeleteIngressPointRequestTypeDef",
    "DeleteRelayRequestTypeDef",
    "DeleteRuleSetRequestTypeDef",
    "DeleteTrafficPolicyRequestTypeDef",
    "DeliverToMailboxActionTypeDef",
    "DeliverToQBusinessActionTypeDef",
    "DeregisterMemberFromAddressListRequestTypeDef",
    "EnvelopeTypeDef",
    "ExportDestinationConfigurationTypeDef",
    "ExportStatusTypeDef",
    "ExportSummaryTypeDef",
    "GetAddonInstanceRequestTypeDef",
    "GetAddonInstanceResponseTypeDef",
    "GetAddonSubscriptionRequestTypeDef",
    "GetAddonSubscriptionResponseTypeDef",
    "GetAddressListImportJobRequestTypeDef",
    "GetAddressListImportJobResponseTypeDef",
    "GetAddressListRequestTypeDef",
    "GetAddressListResponseTypeDef",
    "GetArchiveExportRequestTypeDef",
    "GetArchiveExportResponseTypeDef",
    "GetArchiveMessageContentRequestTypeDef",
    "GetArchiveMessageContentResponseTypeDef",
    "GetArchiveMessageRequestTypeDef",
    "GetArchiveMessageResponseTypeDef",
    "GetArchiveRequestTypeDef",
    "GetArchiveResponseTypeDef",
    "GetArchiveSearchRequestTypeDef",
    "GetArchiveSearchResponseTypeDef",
    "GetArchiveSearchResultsRequestTypeDef",
    "GetArchiveSearchResultsResponseTypeDef",
    "GetIngressPointRequestTypeDef",
    "GetIngressPointResponseTypeDef",
    "GetMemberOfAddressListRequestTypeDef",
    "GetMemberOfAddressListResponseTypeDef",
    "GetRelayRequestTypeDef",
    "GetRelayResponseTypeDef",
    "GetRuleSetRequestTypeDef",
    "GetRuleSetResponseTypeDef",
    "GetTrafficPolicyRequestTypeDef",
    "GetTrafficPolicyResponseTypeDef",
    "ImportDataFormatTypeDef",
    "ImportJobTypeDef",
    "IngressAnalysisTypeDef",
    "IngressBooleanExpressionOutputTypeDef",
    "IngressBooleanExpressionTypeDef",
    "IngressBooleanExpressionUnionTypeDef",
    "IngressBooleanToEvaluateOutputTypeDef",
    "IngressBooleanToEvaluateTypeDef",
    "IngressBooleanToEvaluateUnionTypeDef",
    "IngressIpToEvaluateTypeDef",
    "IngressIpv4ExpressionOutputTypeDef",
    "IngressIpv4ExpressionTypeDef",
    "IngressIpv4ExpressionUnionTypeDef",
    "IngressIpv6ExpressionOutputTypeDef",
    "IngressIpv6ExpressionTypeDef",
    "IngressIpv6ExpressionUnionTypeDef",
    "IngressIpv6ToEvaluateTypeDef",
    "IngressIsInAddressListOutputTypeDef",
    "IngressIsInAddressListTypeDef",
    "IngressIsInAddressListUnionTypeDef",
    "IngressPointAuthConfigurationTypeDef",
    "IngressPointConfigurationTypeDef",
    "IngressPointPasswordConfigurationTypeDef",
    "IngressPointTypeDef",
    "IngressStringExpressionOutputTypeDef",
    "IngressStringExpressionTypeDef",
    "IngressStringExpressionUnionTypeDef",
    "IngressStringToEvaluateTypeDef",
    "IngressTlsProtocolExpressionTypeDef",
    "IngressTlsProtocolToEvaluateTypeDef",
    "ListAddonInstancesRequestPaginateTypeDef",
    "ListAddonInstancesRequestTypeDef",
    "ListAddonInstancesResponseTypeDef",
    "ListAddonSubscriptionsRequestPaginateTypeDef",
    "ListAddonSubscriptionsRequestTypeDef",
    "ListAddonSubscriptionsResponseTypeDef",
    "ListAddressListImportJobsRequestPaginateTypeDef",
    "ListAddressListImportJobsRequestTypeDef",
    "ListAddressListImportJobsResponseTypeDef",
    "ListAddressListsRequestPaginateTypeDef",
    "ListAddressListsRequestTypeDef",
    "ListAddressListsResponseTypeDef",
    "ListArchiveExportsRequestPaginateTypeDef",
    "ListArchiveExportsRequestTypeDef",
    "ListArchiveExportsResponseTypeDef",
    "ListArchiveSearchesRequestPaginateTypeDef",
    "ListArchiveSearchesRequestTypeDef",
    "ListArchiveSearchesResponseTypeDef",
    "ListArchivesRequestPaginateTypeDef",
    "ListArchivesRequestTypeDef",
    "ListArchivesResponseTypeDef",
    "ListIngressPointsRequestPaginateTypeDef",
    "ListIngressPointsRequestTypeDef",
    "ListIngressPointsResponseTypeDef",
    "ListMembersOfAddressListRequestPaginateTypeDef",
    "ListMembersOfAddressListRequestTypeDef",
    "ListMembersOfAddressListResponseTypeDef",
    "ListRelaysRequestPaginateTypeDef",
    "ListRelaysRequestTypeDef",
    "ListRelaysResponseTypeDef",
    "ListRuleSetsRequestPaginateTypeDef",
    "ListRuleSetsRequestTypeDef",
    "ListRuleSetsResponseTypeDef",
    "ListTagsForResourceRequestTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "ListTrafficPoliciesRequestPaginateTypeDef",
    "ListTrafficPoliciesRequestTypeDef",
    "ListTrafficPoliciesResponseTypeDef",
    "MessageBodyTypeDef",
    "MetadataTypeDef",
    "NetworkConfigurationTypeDef",
    "PaginatorConfigTypeDef",
    "PolicyConditionOutputTypeDef",
    "PolicyConditionTypeDef",
    "PolicyConditionUnionTypeDef",
    "PolicyStatementOutputTypeDef",
    "PolicyStatementTypeDef",
    "PolicyStatementUnionTypeDef",
    "PrivateNetworkConfigurationTypeDef",
    "PublicNetworkConfigurationTypeDef",
    "RegisterMemberToAddressListRequestTypeDef",
    "RelayActionTypeDef",
    "RelayAuthenticationOutputTypeDef",
    "RelayAuthenticationTypeDef",
    "RelayAuthenticationUnionTypeDef",
    "RelayTypeDef",
    "ReplaceRecipientActionOutputTypeDef",
    "ReplaceRecipientActionTypeDef",
    "ReplaceRecipientActionUnionTypeDef",
    "ResponseMetadataTypeDef",
    "RowTypeDef",
    "RuleActionOutputTypeDef",
    "RuleActionTypeDef",
    "RuleActionUnionTypeDef",
    "RuleBooleanExpressionOutputTypeDef",
    "RuleBooleanExpressionTypeDef",
    "RuleBooleanExpressionUnionTypeDef",
    "RuleBooleanToEvaluateOutputTypeDef",
    "RuleBooleanToEvaluateTypeDef",
    "RuleBooleanToEvaluateUnionTypeDef",
    "RuleConditionOutputTypeDef",
    "RuleConditionTypeDef",
    "RuleConditionUnionTypeDef",
    "RuleDmarcExpressionOutputTypeDef",
    "RuleDmarcExpressionTypeDef",
    "RuleDmarcExpressionUnionTypeDef",
    "RuleIpExpressionOutputTypeDef",
    "RuleIpExpressionTypeDef",
    "RuleIpExpressionUnionTypeDef",
    "RuleIpToEvaluateTypeDef",
    "RuleIsInAddressListOutputTypeDef",
    "RuleIsInAddressListTypeDef",
    "RuleIsInAddressListUnionTypeDef",
    "RuleNumberExpressionTypeDef",
    "RuleNumberToEvaluateTypeDef",
    "RuleOutputTypeDef",
    "RuleSetTypeDef",
    "RuleStringExpressionOutputTypeDef",
    "RuleStringExpressionTypeDef",
    "RuleStringExpressionUnionTypeDef",
    "RuleStringToEvaluateTypeDef",
    "RuleTypeDef",
    "RuleUnionTypeDef",
    "RuleVerdictExpressionOutputTypeDef",
    "RuleVerdictExpressionTypeDef",
    "RuleVerdictExpressionUnionTypeDef",
    "RuleVerdictToEvaluateTypeDef",
    "S3ActionTypeDef",
    "S3ExportDestinationConfigurationTypeDef",
    "SavedAddressTypeDef",
    "SearchStatusTypeDef",
    "SearchSummaryTypeDef",
    "SendActionTypeDef",
    "SnsActionTypeDef",
    "StartAddressListImportJobRequestTypeDef",
    "StartArchiveExportRequestTypeDef",
    "StartArchiveExportResponseTypeDef",
    "StartArchiveSearchRequestTypeDef",
    "StartArchiveSearchResponseTypeDef",
    "StopAddressListImportJobRequestTypeDef",
    "StopArchiveExportRequestTypeDef",
    "StopArchiveSearchRequestTypeDef",
    "TagResourceRequestTypeDef",
    "TagTypeDef",
    "TimestampTypeDef",
    "TrafficPolicyTypeDef",
    "UntagResourceRequestTypeDef",
    "UpdateArchiveRequestTypeDef",
    "UpdateIngressPointRequestTypeDef",
    "UpdateRelayRequestTypeDef",
    "UpdateRuleSetRequestTypeDef",
    "UpdateTrafficPolicyRequestTypeDef",
)


class AddHeaderActionTypeDef(TypedDict):
    HeaderName: str
    HeaderValue: str


class AddonInstanceTypeDef(TypedDict):
    AddonInstanceId: NotRequired[str]
    AddonSubscriptionId: NotRequired[str]
    AddonName: NotRequired[str]
    AddonInstanceArn: NotRequired[str]
    CreatedTimestamp: NotRequired[datetime]


class AddonSubscriptionTypeDef(TypedDict):
    AddonSubscriptionId: NotRequired[str]
    AddonName: NotRequired[str]
    AddonSubscriptionArn: NotRequired[str]
    CreatedTimestamp: NotRequired[datetime]


class AddressFilterTypeDef(TypedDict):
    AddressPrefix: NotRequired[str]


class AddressListTypeDef(TypedDict):
    AddressListId: str
    AddressListArn: str
    AddressListName: str
    CreatedTimestamp: datetime
    LastUpdatedTimestamp: datetime


class AnalysisTypeDef(TypedDict):
    Analyzer: str
    ResultField: str


class ArchiveActionTypeDef(TypedDict):
    TargetArchive: str
    ActionFailurePolicy: NotRequired[ActionFailurePolicyType]


class ArchiveBooleanToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[Literal["HAS_ATTACHMENTS"]]


class ArchiveRetentionTypeDef(TypedDict):
    RetentionPeriod: NotRequired[RetentionPeriodType]


class ArchiveStringToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[ArchiveStringEmailAttributeType]


class ArchiveTypeDef(TypedDict):
    ArchiveId: str
    ArchiveName: NotRequired[str]
    ArchiveState: NotRequired[ArchiveStateType]
    LastUpdatedTimestamp: NotRequired[datetime]


class TagTypeDef(TypedDict):
    Key: str
    Value: str


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class ImportDataFormatTypeDef(TypedDict):
    ImportDataType: ImportDataTypeType


class IngressPointConfigurationTypeDef(TypedDict):
    SmtpPassword: NotRequired[str]
    SecretArn: NotRequired[str]


class DeleteAddonInstanceRequestTypeDef(TypedDict):
    AddonInstanceId: str


class DeleteAddonSubscriptionRequestTypeDef(TypedDict):
    AddonSubscriptionId: str


class DeleteAddressListRequestTypeDef(TypedDict):
    AddressListId: str


class DeleteArchiveRequestTypeDef(TypedDict):
    ArchiveId: str


class DeleteIngressPointRequestTypeDef(TypedDict):
    IngressPointId: str


class DeleteRelayRequestTypeDef(TypedDict):
    RelayId: str


class DeleteRuleSetRequestTypeDef(TypedDict):
    RuleSetId: str


class DeleteTrafficPolicyRequestTypeDef(TypedDict):
    TrafficPolicyId: str


class DeliverToMailboxActionTypeDef(TypedDict):
    MailboxArn: str
    RoleArn: str
    ActionFailurePolicy: NotRequired[ActionFailurePolicyType]


class DeliverToQBusinessActionTypeDef(TypedDict):
    ApplicationId: str
    IndexId: str
    RoleArn: str
    ActionFailurePolicy: NotRequired[ActionFailurePolicyType]


class DeregisterMemberFromAddressListRequestTypeDef(TypedDict):
    AddressListId: str
    Address: str


class EnvelopeTypeDef(TypedDict):
    Helo: NotRequired[str]
    From: NotRequired[str]
    To: NotRequired[list[str]]


class S3ExportDestinationConfigurationTypeDef(TypedDict):
    S3Location: NotRequired[str]


class ExportStatusTypeDef(TypedDict):
    SubmissionTimestamp: NotRequired[datetime]
    CompletionTimestamp: NotRequired[datetime]
    State: NotRequired[ExportStateType]
    ErrorMessage: NotRequired[str]


class GetAddonInstanceRequestTypeDef(TypedDict):
    AddonInstanceId: str


class GetAddonSubscriptionRequestTypeDef(TypedDict):
    AddonSubscriptionId: str


class GetAddressListImportJobRequestTypeDef(TypedDict):
    JobId: str


class GetAddressListRequestTypeDef(TypedDict):
    AddressListId: str


class GetArchiveExportRequestTypeDef(TypedDict):
    ExportId: str


class GetArchiveMessageContentRequestTypeDef(TypedDict):
    ArchivedMessageId: str


MessageBodyTypeDef = TypedDict(
    "MessageBodyTypeDef",
    {
        "Text": NotRequired[str],
        "Html": NotRequired[str],
        "MessageMalformed": NotRequired[bool],
    },
)


class GetArchiveMessageRequestTypeDef(TypedDict):
    ArchivedMessageId: str


class MetadataTypeDef(TypedDict):
    Timestamp: NotRequired[datetime]
    IngressPointId: NotRequired[str]
    TrafficPolicyId: NotRequired[str]
    RuleSetId: NotRequired[str]
    SenderHostname: NotRequired[str]
    SenderIpAddress: NotRequired[str]
    TlsCipherSuite: NotRequired[str]
    TlsProtocol: NotRequired[str]
    SendingMethod: NotRequired[str]
    SourceIdentity: NotRequired[str]
    SendingPool: NotRequired[str]
    ConfigurationSet: NotRequired[str]
    SourceArn: NotRequired[str]


class GetArchiveRequestTypeDef(TypedDict):
    ArchiveId: str


class GetArchiveSearchRequestTypeDef(TypedDict):
    SearchId: str


class SearchStatusTypeDef(TypedDict):
    SubmissionTimestamp: NotRequired[datetime]
    CompletionTimestamp: NotRequired[datetime]
    State: NotRequired[SearchStateType]
    ErrorMessage: NotRequired[str]


class GetArchiveSearchResultsRequestTypeDef(TypedDict):
    SearchId: str


class GetIngressPointRequestTypeDef(TypedDict):
    IngressPointId: str


class GetMemberOfAddressListRequestTypeDef(TypedDict):
    AddressListId: str
    Address: str


class GetRelayRequestTypeDef(TypedDict):
    RelayId: str


class RelayAuthenticationOutputTypeDef(TypedDict):
    SecretArn: NotRequired[str]
    NoAuthentication: NotRequired[dict[str, Any]]


class GetRuleSetRequestTypeDef(TypedDict):
    RuleSetId: str


class GetTrafficPolicyRequestTypeDef(TypedDict):
    TrafficPolicyId: str


class IngressAnalysisTypeDef(TypedDict):
    Analyzer: str
    ResultField: str


class IngressIsInAddressListOutputTypeDef(TypedDict):
    Attribute: Literal["RECIPIENT"]
    AddressLists: list[str]


class IngressIpToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[Literal["SENDER_IP"]]


class IngressIpv6ToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[Literal["SENDER_IPV6"]]


class IngressIsInAddressListTypeDef(TypedDict):
    Attribute: Literal["RECIPIENT"]
    AddressLists: Sequence[str]


class IngressPointPasswordConfigurationTypeDef(TypedDict):
    SmtpPasswordVersion: NotRequired[str]
    PreviousSmtpPasswordVersion: NotRequired[str]
    PreviousSmtpPasswordExpiryTimestamp: NotRequired[datetime]


IngressPointTypeDef = TypedDict(
    "IngressPointTypeDef",
    {
        "IngressPointName": str,
        "IngressPointId": str,
        "Status": IngressPointStatusType,
        "Type": IngressPointTypeType,
        "ARecord": NotRequired[str],
    },
)


class IngressTlsProtocolToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[Literal["TLS_PROTOCOL"]]


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class ListAddonInstancesRequestTypeDef(TypedDict):
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class ListAddonSubscriptionsRequestTypeDef(TypedDict):
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class ListAddressListImportJobsRequestTypeDef(TypedDict):
    AddressListId: str
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class ListAddressListsRequestTypeDef(TypedDict):
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class ListArchiveExportsRequestTypeDef(TypedDict):
    ArchiveId: str
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class ListArchiveSearchesRequestTypeDef(TypedDict):
    ArchiveId: str
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class ListArchivesRequestTypeDef(TypedDict):
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class ListIngressPointsRequestTypeDef(TypedDict):
    PageSize: NotRequired[int]
    NextToken: NotRequired[str]


class SavedAddressTypeDef(TypedDict):
    Address: str
    CreatedTimestamp: datetime


class ListRelaysRequestTypeDef(TypedDict):
    PageSize: NotRequired[int]
    NextToken: NotRequired[str]


class RelayTypeDef(TypedDict):
    RelayId: NotRequired[str]
    RelayName: NotRequired[str]
    LastModifiedTimestamp: NotRequired[datetime]


class ListRuleSetsRequestTypeDef(TypedDict):
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class RuleSetTypeDef(TypedDict):
    RuleSetId: NotRequired[str]
    RuleSetName: NotRequired[str]
    LastModificationDate: NotRequired[datetime]


class ListTagsForResourceRequestTypeDef(TypedDict):
    ResourceArn: str


class ListTrafficPoliciesRequestTypeDef(TypedDict):
    PageSize: NotRequired[int]
    NextToken: NotRequired[str]


class TrafficPolicyTypeDef(TypedDict):
    TrafficPolicyName: str
    TrafficPolicyId: str
    DefaultAction: AcceptActionType


class PrivateNetworkConfigurationTypeDef(TypedDict):
    VpcEndpointId: str


class PublicNetworkConfigurationTypeDef(TypedDict):
    IpType: IpTypeType


class RegisterMemberToAddressListRequestTypeDef(TypedDict):
    AddressListId: str
    Address: str


class RelayActionTypeDef(TypedDict):
    Relay: str
    ActionFailurePolicy: NotRequired[ActionFailurePolicyType]
    MailFrom: NotRequired[MailFromType]


class RelayAuthenticationTypeDef(TypedDict):
    SecretArn: NotRequired[str]
    NoAuthentication: NotRequired[Mapping[str, Any]]


class ReplaceRecipientActionOutputTypeDef(TypedDict):
    ReplaceWith: NotRequired[list[str]]


class ReplaceRecipientActionTypeDef(TypedDict):
    ReplaceWith: NotRequired[Sequence[str]]


class S3ActionTypeDef(TypedDict):
    RoleArn: str
    S3Bucket: str
    ActionFailurePolicy: NotRequired[ActionFailurePolicyType]
    S3Prefix: NotRequired[str]
    S3SseKmsKeyId: NotRequired[str]


class SendActionTypeDef(TypedDict):
    RoleArn: str
    ActionFailurePolicy: NotRequired[ActionFailurePolicyType]


class SnsActionTypeDef(TypedDict):
    TopicArn: str
    RoleArn: str
    ActionFailurePolicy: NotRequired[ActionFailurePolicyType]
    Encoding: NotRequired[SnsNotificationEncodingType]
    PayloadType: NotRequired[SnsNotificationPayloadTypeType]


class RuleIsInAddressListOutputTypeDef(TypedDict):
    Attribute: RuleAddressListEmailAttributeType
    AddressLists: list[str]


class RuleDmarcExpressionOutputTypeDef(TypedDict):
    Operator: RuleDmarcOperatorType
    Values: list[RuleDmarcPolicyType]


class RuleDmarcExpressionTypeDef(TypedDict):
    Operator: RuleDmarcOperatorType
    Values: Sequence[RuleDmarcPolicyType]


class RuleIpToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[Literal["SOURCE_IP"]]


class RuleIsInAddressListTypeDef(TypedDict):
    Attribute: RuleAddressListEmailAttributeType
    AddressLists: Sequence[str]


class RuleNumberToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[Literal["MESSAGE_SIZE"]]


class StartAddressListImportJobRequestTypeDef(TypedDict):
    JobId: str


TimestampTypeDef = Union[datetime, str]


class StopAddressListImportJobRequestTypeDef(TypedDict):
    JobId: str


class StopArchiveExportRequestTypeDef(TypedDict):
    ExportId: str


class StopArchiveSearchRequestTypeDef(TypedDict):
    SearchId: str


class UntagResourceRequestTypeDef(TypedDict):
    ResourceArn: str
    TagKeys: Sequence[str]


class ListMembersOfAddressListRequestTypeDef(TypedDict):
    AddressListId: str
    Filter: NotRequired[AddressFilterTypeDef]
    NextToken: NotRequired[str]
    PageSize: NotRequired[int]


class RuleStringToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[RuleStringEmailAttributeType]
    MimeHeaderAttribute: NotRequired[str]
    Analysis: NotRequired[AnalysisTypeDef]


class RuleVerdictToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[RuleVerdictAttributeType]
    Analysis: NotRequired[AnalysisTypeDef]


class ArchiveBooleanExpressionTypeDef(TypedDict):
    Evaluate: ArchiveBooleanToEvaluateTypeDef
    Operator: ArchiveBooleanOperatorType


class UpdateArchiveRequestTypeDef(TypedDict):
    ArchiveId: str
    ArchiveName: NotRequired[str]
    Retention: NotRequired[ArchiveRetentionTypeDef]


class ArchiveStringExpressionOutputTypeDef(TypedDict):
    Evaluate: ArchiveStringToEvaluateTypeDef
    Operator: Literal["CONTAINS"]
    Values: list[str]


class ArchiveStringExpressionTypeDef(TypedDict):
    Evaluate: ArchiveStringToEvaluateTypeDef
    Operator: Literal["CONTAINS"]
    Values: Sequence[str]


class CreateAddonInstanceRequestTypeDef(TypedDict):
    AddonSubscriptionId: str
    ClientToken: NotRequired[str]
    Tags: NotRequired[Sequence[TagTypeDef]]


class CreateAddonSubscriptionRequestTypeDef(TypedDict):
    AddonName: str
    ClientToken: NotRequired[str]
    Tags: NotRequired[Sequence[TagTypeDef]]


class CreateAddressListRequestTypeDef(TypedDict):
    AddressListName: str
    ClientToken: NotRequired[str]
    Tags: NotRequired[Sequence[TagTypeDef]]


class CreateArchiveRequestTypeDef(TypedDict):
    ArchiveName: str
    ClientToken: NotRequired[str]
    Retention: NotRequired[ArchiveRetentionTypeDef]
    KmsKeyArn: NotRequired[str]
    Tags: NotRequired[Sequence[TagTypeDef]]


class TagResourceRequestTypeDef(TypedDict):
    ResourceArn: str
    Tags: Sequence[TagTypeDef]


class CreateAddonInstanceResponseTypeDef(TypedDict):
    AddonInstanceId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateAddonSubscriptionResponseTypeDef(TypedDict):
    AddonSubscriptionId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateAddressListImportJobResponseTypeDef(TypedDict):
    JobId: str
    PreSignedUrl: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateAddressListResponseTypeDef(TypedDict):
    AddressListId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateArchiveResponseTypeDef(TypedDict):
    ArchiveId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateIngressPointResponseTypeDef(TypedDict):
    IngressPointId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateRelayResponseTypeDef(TypedDict):
    RelayId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateRuleSetResponseTypeDef(TypedDict):
    RuleSetId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateTrafficPolicyResponseTypeDef(TypedDict):
    TrafficPolicyId: str
    ResponseMetadata: ResponseMetadataTypeDef


class GetAddonInstanceResponseTypeDef(TypedDict):
    AddonSubscriptionId: str
    AddonName: str
    AddonInstanceArn: str
    CreatedTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class GetAddonSubscriptionResponseTypeDef(TypedDict):
    AddonName: str
    AddonSubscriptionArn: str
    CreatedTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class GetAddressListResponseTypeDef(TypedDict):
    AddressListId: str
    AddressListArn: str
    AddressListName: str
    CreatedTimestamp: datetime
    LastUpdatedTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class GetArchiveResponseTypeDef(TypedDict):
    ArchiveId: str
    ArchiveName: str
    ArchiveArn: str
    ArchiveState: ArchiveStateType
    Retention: ArchiveRetentionTypeDef
    CreatedTimestamp: datetime
    LastUpdatedTimestamp: datetime
    KmsKeyArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class GetMemberOfAddressListResponseTypeDef(TypedDict):
    Address: str
    CreatedTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class ListAddonInstancesResponseTypeDef(TypedDict):
    AddonInstances: list[AddonInstanceTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListAddonSubscriptionsResponseTypeDef(TypedDict):
    AddonSubscriptions: list[AddonSubscriptionTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListAddressListsResponseTypeDef(TypedDict):
    AddressLists: list[AddressListTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListArchivesResponseTypeDef(TypedDict):
    Archives: list[ArchiveTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListTagsForResourceResponseTypeDef(TypedDict):
    Tags: list[TagTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class StartArchiveExportResponseTypeDef(TypedDict):
    ExportId: str
    ResponseMetadata: ResponseMetadataTypeDef


class StartArchiveSearchResponseTypeDef(TypedDict):
    SearchId: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateAddressListImportJobRequestTypeDef(TypedDict):
    AddressListId: str
    Name: str
    ImportDataFormat: ImportDataFormatTypeDef
    ClientToken: NotRequired[str]


class GetAddressListImportJobResponseTypeDef(TypedDict):
    JobId: str
    Name: str
    Status: ImportJobStatusType
    PreSignedUrl: str
    ImportedItemsCount: int
    FailedItemsCount: int
    ImportDataFormat: ImportDataFormatTypeDef
    AddressListId: str
    CreatedTimestamp: datetime
    StartTimestamp: datetime
    CompletedTimestamp: datetime
    Error: str
    ResponseMetadata: ResponseMetadataTypeDef


class ImportJobTypeDef(TypedDict):
    JobId: str
    Name: str
    Status: ImportJobStatusType
    PreSignedUrl: str
    ImportDataFormat: ImportDataFormatTypeDef
    AddressListId: str
    CreatedTimestamp: datetime
    ImportedItemsCount: NotRequired[int]
    FailedItemsCount: NotRequired[int]
    StartTimestamp: NotRequired[datetime]
    CompletedTimestamp: NotRequired[datetime]
    Error: NotRequired[str]


class UpdateIngressPointRequestTypeDef(TypedDict):
    IngressPointId: str
    IngressPointName: NotRequired[str]
    StatusToUpdate: NotRequired[IngressPointStatusToUpdateType]
    RuleSetId: NotRequired[str]
    TrafficPolicyId: NotRequired[str]
    IngressPointConfiguration: NotRequired[IngressPointConfigurationTypeDef]


class RowTypeDef(TypedDict):
    ArchivedMessageId: NotRequired[str]
    ReceivedTimestamp: NotRequired[datetime]
    Date: NotRequired[str]
    To: NotRequired[str]
    From: NotRequired[str]
    Cc: NotRequired[str]
    Subject: NotRequired[str]
    MessageId: NotRequired[str]
    HasAttachments: NotRequired[bool]
    ReceivedHeaders: NotRequired[list[str]]
    InReplyTo: NotRequired[str]
    XMailer: NotRequired[str]
    XOriginalMailer: NotRequired[str]
    XPriority: NotRequired[str]
    IngressPointId: NotRequired[str]
    SenderHostname: NotRequired[str]
    SenderIpAddress: NotRequired[str]
    Envelope: NotRequired[EnvelopeTypeDef]
    SourceArn: NotRequired[str]


class ExportDestinationConfigurationTypeDef(TypedDict):
    S3: NotRequired[S3ExportDestinationConfigurationTypeDef]


class ExportSummaryTypeDef(TypedDict):
    ExportId: NotRequired[str]
    Status: NotRequired[ExportStatusTypeDef]


class GetArchiveMessageContentResponseTypeDef(TypedDict):
    Body: MessageBodyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetArchiveMessageResponseTypeDef(TypedDict):
    MessageDownloadLink: str
    Metadata: MetadataTypeDef
    Envelope: EnvelopeTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class SearchSummaryTypeDef(TypedDict):
    SearchId: NotRequired[str]
    Status: NotRequired[SearchStatusTypeDef]


class GetRelayResponseTypeDef(TypedDict):
    RelayId: str
    RelayArn: str
    RelayName: str
    ServerName: str
    ServerPort: int
    Authentication: RelayAuthenticationOutputTypeDef
    CreatedTimestamp: datetime
    LastModifiedTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class IngressStringToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[Literal["RECIPIENT"]]
    Analysis: NotRequired[IngressAnalysisTypeDef]


class IngressBooleanToEvaluateOutputTypeDef(TypedDict):
    Analysis: NotRequired[IngressAnalysisTypeDef]
    IsInAddressList: NotRequired[IngressIsInAddressListOutputTypeDef]


class IngressIpv4ExpressionOutputTypeDef(TypedDict):
    Evaluate: IngressIpToEvaluateTypeDef
    Operator: IngressIpOperatorType
    Values: list[str]


class IngressIpv4ExpressionTypeDef(TypedDict):
    Evaluate: IngressIpToEvaluateTypeDef
    Operator: IngressIpOperatorType
    Values: Sequence[str]


class IngressIpv6ExpressionOutputTypeDef(TypedDict):
    Evaluate: IngressIpv6ToEvaluateTypeDef
    Operator: IngressIpOperatorType
    Values: list[str]


class IngressIpv6ExpressionTypeDef(TypedDict):
    Evaluate: IngressIpv6ToEvaluateTypeDef
    Operator: IngressIpOperatorType
    Values: Sequence[str]


IngressIsInAddressListUnionTypeDef = Union[
    IngressIsInAddressListTypeDef, IngressIsInAddressListOutputTypeDef
]


class IngressPointAuthConfigurationTypeDef(TypedDict):
    IngressPointPasswordConfiguration: NotRequired[IngressPointPasswordConfigurationTypeDef]
    SecretArn: NotRequired[str]


class ListIngressPointsResponseTypeDef(TypedDict):
    IngressPoints: list[IngressPointTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class IngressTlsProtocolExpressionTypeDef(TypedDict):
    Evaluate: IngressTlsProtocolToEvaluateTypeDef
    Operator: IngressTlsProtocolOperatorType
    Value: IngressTlsProtocolAttributeType


class ListAddonInstancesRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListAddonSubscriptionsRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListAddressListImportJobsRequestPaginateTypeDef(TypedDict):
    AddressListId: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListAddressListsRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListArchiveExportsRequestPaginateTypeDef(TypedDict):
    ArchiveId: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListArchiveSearchesRequestPaginateTypeDef(TypedDict):
    ArchiveId: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListArchivesRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListIngressPointsRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListMembersOfAddressListRequestPaginateTypeDef(TypedDict):
    AddressListId: str
    Filter: NotRequired[AddressFilterTypeDef]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListRelaysRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListRuleSetsRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListTrafficPoliciesRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListMembersOfAddressListResponseTypeDef(TypedDict):
    Addresses: list[SavedAddressTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListRelaysResponseTypeDef(TypedDict):
    Relays: list[RelayTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListRuleSetsResponseTypeDef(TypedDict):
    RuleSets: list[RuleSetTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListTrafficPoliciesResponseTypeDef(TypedDict):
    TrafficPolicies: list[TrafficPolicyTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class NetworkConfigurationTypeDef(TypedDict):
    PublicNetworkConfiguration: NotRequired[PublicNetworkConfigurationTypeDef]
    PrivateNetworkConfiguration: NotRequired[PrivateNetworkConfigurationTypeDef]


RelayAuthenticationUnionTypeDef = Union[
    RelayAuthenticationTypeDef, RelayAuthenticationOutputTypeDef
]
ReplaceRecipientActionUnionTypeDef = Union[
    ReplaceRecipientActionTypeDef, ReplaceRecipientActionOutputTypeDef
]


class RuleActionOutputTypeDef(TypedDict):
    Drop: NotRequired[dict[str, Any]]
    Relay: NotRequired[RelayActionTypeDef]
    Archive: NotRequired[ArchiveActionTypeDef]
    WriteToS3: NotRequired[S3ActionTypeDef]
    Send: NotRequired[SendActionTypeDef]
    AddHeader: NotRequired[AddHeaderActionTypeDef]
    ReplaceRecipient: NotRequired[ReplaceRecipientActionOutputTypeDef]
    DeliverToMailbox: NotRequired[DeliverToMailboxActionTypeDef]
    DeliverToQBusiness: NotRequired[DeliverToQBusinessActionTypeDef]
    PublishToSns: NotRequired[SnsActionTypeDef]


class RuleBooleanToEvaluateOutputTypeDef(TypedDict):
    Attribute: NotRequired[RuleBooleanEmailAttributeType]
    Analysis: NotRequired[AnalysisTypeDef]
    IsInAddressList: NotRequired[RuleIsInAddressListOutputTypeDef]


RuleDmarcExpressionUnionTypeDef = Union[
    RuleDmarcExpressionTypeDef, RuleDmarcExpressionOutputTypeDef
]


class RuleIpExpressionOutputTypeDef(TypedDict):
    Evaluate: RuleIpToEvaluateTypeDef
    Operator: RuleIpOperatorType
    Values: list[str]


class RuleIpExpressionTypeDef(TypedDict):
    Evaluate: RuleIpToEvaluateTypeDef
    Operator: RuleIpOperatorType
    Values: Sequence[str]


RuleIsInAddressListUnionTypeDef = Union[
    RuleIsInAddressListTypeDef, RuleIsInAddressListOutputTypeDef
]


class RuleNumberExpressionTypeDef(TypedDict):
    Evaluate: RuleNumberToEvaluateTypeDef
    Operator: RuleNumberOperatorType
    Value: float


class RuleStringExpressionOutputTypeDef(TypedDict):
    Evaluate: RuleStringToEvaluateTypeDef
    Operator: RuleStringOperatorType
    Values: list[str]


class RuleStringExpressionTypeDef(TypedDict):
    Evaluate: RuleStringToEvaluateTypeDef
    Operator: RuleStringOperatorType
    Values: Sequence[str]


class RuleVerdictExpressionOutputTypeDef(TypedDict):
    Evaluate: RuleVerdictToEvaluateTypeDef
    Operator: RuleVerdictOperatorType
    Values: list[RuleVerdictType]


class RuleVerdictExpressionTypeDef(TypedDict):
    Evaluate: RuleVerdictToEvaluateTypeDef
    Operator: RuleVerdictOperatorType
    Values: Sequence[RuleVerdictType]


class ArchiveFilterConditionOutputTypeDef(TypedDict):
    StringExpression: NotRequired[ArchiveStringExpressionOutputTypeDef]
    BooleanExpression: NotRequired[ArchiveBooleanExpressionTypeDef]


class ArchiveFilterConditionTypeDef(TypedDict):
    StringExpression: NotRequired[ArchiveStringExpressionTypeDef]
    BooleanExpression: NotRequired[ArchiveBooleanExpressionTypeDef]


class ListAddressListImportJobsResponseTypeDef(TypedDict):
    ImportJobs: list[ImportJobTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class GetArchiveSearchResultsResponseTypeDef(TypedDict):
    Rows: list[RowTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class ListArchiveExportsResponseTypeDef(TypedDict):
    Exports: list[ExportSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListArchiveSearchesResponseTypeDef(TypedDict):
    Searches: list[SearchSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class IngressStringExpressionOutputTypeDef(TypedDict):
    Evaluate: IngressStringToEvaluateTypeDef
    Operator: IngressStringOperatorType
    Values: list[str]


class IngressStringExpressionTypeDef(TypedDict):
    Evaluate: IngressStringToEvaluateTypeDef
    Operator: IngressStringOperatorType
    Values: Sequence[str]


class IngressBooleanExpressionOutputTypeDef(TypedDict):
    Evaluate: IngressBooleanToEvaluateOutputTypeDef
    Operator: IngressBooleanOperatorType


IngressIpv4ExpressionUnionTypeDef = Union[
    IngressIpv4ExpressionTypeDef, IngressIpv4ExpressionOutputTypeDef
]
IngressIpv6ExpressionUnionTypeDef = Union[
    IngressIpv6ExpressionTypeDef, IngressIpv6ExpressionOutputTypeDef
]


class IngressBooleanToEvaluateTypeDef(TypedDict):
    Analysis: NotRequired[IngressAnalysisTypeDef]
    IsInAddressList: NotRequired[IngressIsInAddressListUnionTypeDef]


CreateIngressPointRequestTypeDef = TypedDict(
    "CreateIngressPointRequestTypeDef",
    {
        "IngressPointName": str,
        "Type": IngressPointTypeType,
        "RuleSetId": str,
        "TrafficPolicyId": str,
        "ClientToken": NotRequired[str],
        "IngressPointConfiguration": NotRequired[IngressPointConfigurationTypeDef],
        "NetworkConfiguration": NotRequired[NetworkConfigurationTypeDef],
        "Tags": NotRequired[Sequence[TagTypeDef]],
    },
)
GetIngressPointResponseTypeDef = TypedDict(
    "GetIngressPointResponseTypeDef",
    {
        "IngressPointId": str,
        "IngressPointName": str,
        "IngressPointArn": str,
        "Status": IngressPointStatusType,
        "Type": IngressPointTypeType,
        "ARecord": str,
        "RuleSetId": str,
        "TrafficPolicyId": str,
        "IngressPointAuthConfiguration": IngressPointAuthConfigurationTypeDef,
        "NetworkConfiguration": NetworkConfigurationTypeDef,
        "CreatedTimestamp": datetime,
        "LastUpdatedTimestamp": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)


class CreateRelayRequestTypeDef(TypedDict):
    RelayName: str
    ServerName: str
    ServerPort: int
    Authentication: RelayAuthenticationUnionTypeDef
    ClientToken: NotRequired[str]
    Tags: NotRequired[Sequence[TagTypeDef]]


class UpdateRelayRequestTypeDef(TypedDict):
    RelayId: str
    RelayName: NotRequired[str]
    ServerName: NotRequired[str]
    ServerPort: NotRequired[int]
    Authentication: NotRequired[RelayAuthenticationUnionTypeDef]


class RuleActionTypeDef(TypedDict):
    Drop: NotRequired[Mapping[str, Any]]
    Relay: NotRequired[RelayActionTypeDef]
    Archive: NotRequired[ArchiveActionTypeDef]
    WriteToS3: NotRequired[S3ActionTypeDef]
    Send: NotRequired[SendActionTypeDef]
    AddHeader: NotRequired[AddHeaderActionTypeDef]
    ReplaceRecipient: NotRequired[ReplaceRecipientActionUnionTypeDef]
    DeliverToMailbox: NotRequired[DeliverToMailboxActionTypeDef]
    DeliverToQBusiness: NotRequired[DeliverToQBusinessActionTypeDef]
    PublishToSns: NotRequired[SnsActionTypeDef]


class RuleBooleanExpressionOutputTypeDef(TypedDict):
    Evaluate: RuleBooleanToEvaluateOutputTypeDef
    Operator: RuleBooleanOperatorType


RuleIpExpressionUnionTypeDef = Union[RuleIpExpressionTypeDef, RuleIpExpressionOutputTypeDef]


class RuleBooleanToEvaluateTypeDef(TypedDict):
    Attribute: NotRequired[RuleBooleanEmailAttributeType]
    Analysis: NotRequired[AnalysisTypeDef]
    IsInAddressList: NotRequired[RuleIsInAddressListUnionTypeDef]


RuleStringExpressionUnionTypeDef = Union[
    RuleStringExpressionTypeDef, RuleStringExpressionOutputTypeDef
]
RuleVerdictExpressionUnionTypeDef = Union[
    RuleVerdictExpressionTypeDef, RuleVerdictExpressionOutputTypeDef
]


class ArchiveFiltersOutputTypeDef(TypedDict):
    Include: NotRequired[list[ArchiveFilterConditionOutputTypeDef]]
    Unless: NotRequired[list[ArchiveFilterConditionOutputTypeDef]]


class ArchiveFiltersTypeDef(TypedDict):
    Include: NotRequired[Sequence[ArchiveFilterConditionTypeDef]]
    Unless: NotRequired[Sequence[ArchiveFilterConditionTypeDef]]


IngressStringExpressionUnionTypeDef = Union[
    IngressStringExpressionTypeDef, IngressStringExpressionOutputTypeDef
]


class PolicyConditionOutputTypeDef(TypedDict):
    StringExpression: NotRequired[IngressStringExpressionOutputTypeDef]
    IpExpression: NotRequired[IngressIpv4ExpressionOutputTypeDef]
    Ipv6Expression: NotRequired[IngressIpv6ExpressionOutputTypeDef]
    TlsExpression: NotRequired[IngressTlsProtocolExpressionTypeDef]
    BooleanExpression: NotRequired[IngressBooleanExpressionOutputTypeDef]


IngressBooleanToEvaluateUnionTypeDef = Union[
    IngressBooleanToEvaluateTypeDef, IngressBooleanToEvaluateOutputTypeDef
]
RuleActionUnionTypeDef = Union[RuleActionTypeDef, RuleActionOutputTypeDef]


class RuleConditionOutputTypeDef(TypedDict):
    BooleanExpression: NotRequired[RuleBooleanExpressionOutputTypeDef]
    StringExpression: NotRequired[RuleStringExpressionOutputTypeDef]
    NumberExpression: NotRequired[RuleNumberExpressionTypeDef]
    IpExpression: NotRequired[RuleIpExpressionOutputTypeDef]
    VerdictExpression: NotRequired[RuleVerdictExpressionOutputTypeDef]
    DmarcExpression: NotRequired[RuleDmarcExpressionOutputTypeDef]


RuleBooleanToEvaluateUnionTypeDef = Union[
    RuleBooleanToEvaluateTypeDef, RuleBooleanToEvaluateOutputTypeDef
]


class GetArchiveExportResponseTypeDef(TypedDict):
    ArchiveId: str
    Filters: ArchiveFiltersOutputTypeDef
    FromTimestamp: datetime
    ToTimestamp: datetime
    MaxResults: int
    ExportDestinationConfiguration: ExportDestinationConfigurationTypeDef
    Status: ExportStatusTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetArchiveSearchResponseTypeDef(TypedDict):
    ArchiveId: str
    Filters: ArchiveFiltersOutputTypeDef
    FromTimestamp: datetime
    ToTimestamp: datetime
    MaxResults: int
    Status: SearchStatusTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


ArchiveFiltersUnionTypeDef = Union[ArchiveFiltersTypeDef, ArchiveFiltersOutputTypeDef]


class PolicyStatementOutputTypeDef(TypedDict):
    Conditions: list[PolicyConditionOutputTypeDef]
    Action: AcceptActionType


class IngressBooleanExpressionTypeDef(TypedDict):
    Evaluate: IngressBooleanToEvaluateUnionTypeDef
    Operator: IngressBooleanOperatorType


class RuleOutputTypeDef(TypedDict):
    Actions: list[RuleActionOutputTypeDef]
    Name: NotRequired[str]
    Conditions: NotRequired[list[RuleConditionOutputTypeDef]]
    Unless: NotRequired[list[RuleConditionOutputTypeDef]]


class RuleBooleanExpressionTypeDef(TypedDict):
    Evaluate: RuleBooleanToEvaluateUnionTypeDef
    Operator: RuleBooleanOperatorType


class StartArchiveExportRequestTypeDef(TypedDict):
    ArchiveId: str
    FromTimestamp: TimestampTypeDef
    ToTimestamp: TimestampTypeDef
    ExportDestinationConfiguration: ExportDestinationConfigurationTypeDef
    Filters: NotRequired[ArchiveFiltersUnionTypeDef]
    MaxResults: NotRequired[int]
    IncludeMetadata: NotRequired[bool]


class StartArchiveSearchRequestTypeDef(TypedDict):
    ArchiveId: str
    FromTimestamp: TimestampTypeDef
    ToTimestamp: TimestampTypeDef
    MaxResults: int
    Filters: NotRequired[ArchiveFiltersUnionTypeDef]


class GetTrafficPolicyResponseTypeDef(TypedDict):
    TrafficPolicyName: str
    TrafficPolicyId: str
    TrafficPolicyArn: str
    PolicyStatements: list[PolicyStatementOutputTypeDef]
    MaxMessageSizeBytes: int
    DefaultAction: AcceptActionType
    CreatedTimestamp: datetime
    LastUpdatedTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


IngressBooleanExpressionUnionTypeDef = Union[
    IngressBooleanExpressionTypeDef, IngressBooleanExpressionOutputTypeDef
]


class GetRuleSetResponseTypeDef(TypedDict):
    RuleSetId: str
    RuleSetArn: str
    RuleSetName: str
    CreatedDate: datetime
    LastModificationDate: datetime
    Rules: list[RuleOutputTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


RuleBooleanExpressionUnionTypeDef = Union[
    RuleBooleanExpressionTypeDef, RuleBooleanExpressionOutputTypeDef
]


class PolicyConditionTypeDef(TypedDict):
    StringExpression: NotRequired[IngressStringExpressionUnionTypeDef]
    IpExpression: NotRequired[IngressIpv4ExpressionUnionTypeDef]
    Ipv6Expression: NotRequired[IngressIpv6ExpressionUnionTypeDef]
    TlsExpression: NotRequired[IngressTlsProtocolExpressionTypeDef]
    BooleanExpression: NotRequired[IngressBooleanExpressionUnionTypeDef]


class RuleConditionTypeDef(TypedDict):
    BooleanExpression: NotRequired[RuleBooleanExpressionUnionTypeDef]
    StringExpression: NotRequired[RuleStringExpressionUnionTypeDef]
    NumberExpression: NotRequired[RuleNumberExpressionTypeDef]
    IpExpression: NotRequired[RuleIpExpressionUnionTypeDef]
    VerdictExpression: NotRequired[RuleVerdictExpressionUnionTypeDef]
    DmarcExpression: NotRequired[RuleDmarcExpressionUnionTypeDef]


PolicyConditionUnionTypeDef = Union[PolicyConditionTypeDef, PolicyConditionOutputTypeDef]
RuleConditionUnionTypeDef = Union[RuleConditionTypeDef, RuleConditionOutputTypeDef]


class PolicyStatementTypeDef(TypedDict):
    Conditions: Sequence[PolicyConditionUnionTypeDef]
    Action: AcceptActionType


class RuleTypeDef(TypedDict):
    Actions: Sequence[RuleActionUnionTypeDef]
    Name: NotRequired[str]
    Conditions: NotRequired[Sequence[RuleConditionUnionTypeDef]]
    Unless: NotRequired[Sequence[RuleConditionUnionTypeDef]]


PolicyStatementUnionTypeDef = Union[PolicyStatementTypeDef, PolicyStatementOutputTypeDef]
RuleUnionTypeDef = Union[RuleTypeDef, RuleOutputTypeDef]


class CreateTrafficPolicyRequestTypeDef(TypedDict):
    TrafficPolicyName: str
    PolicyStatements: Sequence[PolicyStatementUnionTypeDef]
    DefaultAction: AcceptActionType
    ClientToken: NotRequired[str]
    MaxMessageSizeBytes: NotRequired[int]
    Tags: NotRequired[Sequence[TagTypeDef]]


class UpdateTrafficPolicyRequestTypeDef(TypedDict):
    TrafficPolicyId: str
    TrafficPolicyName: NotRequired[str]
    PolicyStatements: NotRequired[Sequence[PolicyStatementUnionTypeDef]]
    DefaultAction: NotRequired[AcceptActionType]
    MaxMessageSizeBytes: NotRequired[int]


class CreateRuleSetRequestTypeDef(TypedDict):
    RuleSetName: str
    Rules: Sequence[RuleUnionTypeDef]
    ClientToken: NotRequired[str]
    Tags: NotRequired[Sequence[TagTypeDef]]


class UpdateRuleSetRequestTypeDef(TypedDict):
    RuleSetId: str
    RuleSetName: NotRequired[str]
    Rules: NotRequired[Sequence[RuleUnionTypeDef]]



"""
Type annotations for mailmanager service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_mailmanager.client import MailManagerClient

    session = Session()
    client: MailManagerClient = session.client("mailmanager")
    ```
"""

from __future__ import annotations

import sys
from collections.abc import Mapping
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    ListAddonInstancesPaginator,
    ListAddonSubscriptionsPaginator,
    ListAddressListImportJobsPaginator,
    ListAddressListsPaginator,
    ListArchiveExportsPaginator,
    ListArchiveSearchesPaginator,
    ListArchivesPaginator,
    ListIngressPointsPaginator,
    ListMembersOfAddressListPaginator,
    ListRelaysPaginator,
    ListRuleSetsPaginator,
    ListTrafficPoliciesPaginator,
)
from .type_defs import (
    CreateAddonInstanceRequestTypeDef,
    CreateAddonInstanceResponseTypeDef,
    CreateAddonSubscriptionRequestTypeDef,
    CreateAddonSubscriptionResponseTypeDef,
    CreateAddressListImportJobRequestTypeDef,
    CreateAddressListImportJobResponseTypeDef,
    CreateAddressListRequestTypeDef,
    CreateAddressListResponseTypeDef,
    CreateArchiveRequestTypeDef,
    CreateArchiveResponseTypeDef,
    CreateIngressPointRequestTypeDef,
    CreateIngressPointResponseTypeDef,
    CreateRelayRequestTypeDef,
    CreateRelayResponseTypeDef,
    CreateRuleSetRequestTypeDef,
    CreateRuleSetResponseTypeDef,
    CreateTrafficPolicyRequestTypeDef,
    CreateTrafficPolicyResponseTypeDef,
    DeleteAddonInstanceRequestTypeDef,
    DeleteAddonSubscriptionRequestTypeDef,
    DeleteAddressListRequestTypeDef,
    DeleteArchiveRequestTypeDef,
    DeleteIngressPointRequestTypeDef,
    DeleteRelayRequestTypeDef,
    DeleteRuleSetRequestTypeDef,
    DeleteTrafficPolicyRequestTypeDef,
    DeregisterMemberFromAddressListRequestTypeDef,
    GetAddonInstanceRequestTypeDef,
    GetAddonInstanceResponseTypeDef,
    GetAddonSubscriptionRequestTypeDef,
    GetAddonSubscriptionResponseTypeDef,
    GetAddressListImportJobRequestTypeDef,
    GetAddressListImportJobResponseTypeDef,
    GetAddressListRequestTypeDef,
    GetAddressListResponseTypeDef,
    GetArchiveExportRequestTypeDef,
    GetArchiveExportResponseTypeDef,
    GetArchiveMessageContentRequestTypeDef,
    GetArchiveMessageContentResponseTypeDef,
    GetArchiveMessageRequestTypeDef,
    GetArchiveMessageResponseTypeDef,
    GetArchiveRequestTypeDef,
    GetArchiveResponseTypeDef,
    GetArchiveSearchRequestTypeDef,
    GetArchiveSearchResponseTypeDef,
    GetArchiveSearchResultsRequestTypeDef,
    GetArchiveSearchResultsResponseTypeDef,
    GetIngressPointRequestTypeDef,
    GetIngressPointResponseTypeDef,
    GetMemberOfAddressListRequestTypeDef,
    GetMemberOfAddressListResponseTypeDef,
    GetRelayRequestTypeDef,
    GetRelayResponseTypeDef,
    GetRuleSetRequestTypeDef,
    GetRuleSetResponseTypeDef,
    GetTrafficPolicyRequestTypeDef,
    GetTrafficPolicyResponseTypeDef,
    ListAddonInstancesRequestTypeDef,
    ListAddonInstancesResponseTypeDef,
    ListAddonSubscriptionsRequestTypeDef,
    ListAddonSubscriptionsResponseTypeDef,
    ListAddressListImportJobsRequestTypeDef,
    ListAddressListImportJobsResponseTypeDef,
    ListAddressListsRequestTypeDef,
    ListAddressListsResponseTypeDef,
    ListArchiveExportsRequestTypeDef,
    ListArchiveExportsResponseTypeDef,
    ListArchiveSearchesRequestTypeDef,
    ListArchiveSearchesResponseTypeDef,
    ListArchivesRequestTypeDef,
    ListArchivesResponseTypeDef,
    ListIngressPointsRequestTypeDef,
    ListIngressPointsResponseTypeDef,
    ListMembersOfAddressListRequestTypeDef,
    ListMembersOfAddressListResponseTypeDef,
    ListRelaysRequestTypeDef,
    ListRelaysResponseTypeDef,
    ListRuleSetsRequestTypeDef,
    ListRuleSetsResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTrafficPoliciesRequestTypeDef,
    ListTrafficPoliciesResponseTypeDef,
    RegisterMemberToAddressListRequestTypeDef,
    StartAddressListImportJobRequestTypeDef,
    StartArchiveExportRequestTypeDef,
    StartArchiveExportResponseTypeDef,
    StartArchiveSearchRequestTypeDef,
    StartArchiveSearchResponseTypeDef,
    StopAddressListImportJobRequestTypeDef,
    StopArchiveExportRequestTypeDef,
    StopArchiveSearchRequestTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateArchiveRequestTypeDef,
    UpdateIngressPointRequestTypeDef,
    UpdateRelayRequestTypeDef,
    UpdateRuleSetRequestTypeDef,
    UpdateTrafficPolicyRequestTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack


__all__ = ("MailManagerClient",)


class Exceptions(BaseClientExceptions):
    AccessDeniedException: type[BotocoreClientError]
    ClientError: type[BotocoreClientError]
    ConflictException: type[BotocoreClientError]
    ResourceNotFoundException: type[BotocoreClientError]
    ServiceQuotaExceededException: type[BotocoreClientError]
    ThrottlingException: type[BotocoreClientError]
    ValidationException: type[BotocoreClientError]


class MailManagerClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager.html#MailManager.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        MailManagerClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager.html#MailManager.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#generate_presigned_url)
        """

    def create_addon_instance(
        self, **kwargs: Unpack[CreateAddonInstanceRequestTypeDef]
    ) -> CreateAddonInstanceResponseTypeDef:
        """
        Creates an Add On instance for the subscription indicated in the request.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_addon_instance.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_addon_instance)
        """

    def create_addon_subscription(
        self, **kwargs: Unpack[CreateAddonSubscriptionRequestTypeDef]
    ) -> CreateAddonSubscriptionResponseTypeDef:
        """
        Creates a subscription for an Add On representing the acceptance of its terms
        of use and additional pricing.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_addon_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_addon_subscription)
        """

    def create_address_list(
        self, **kwargs: Unpack[CreateAddressListRequestTypeDef]
    ) -> CreateAddressListResponseTypeDef:
        """
        Creates a new address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_address_list.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_address_list)
        """

    def create_address_list_import_job(
        self, **kwargs: Unpack[CreateAddressListImportJobRequestTypeDef]
    ) -> CreateAddressListImportJobResponseTypeDef:
        """
        Creates an import job for an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_address_list_import_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_address_list_import_job)
        """

    def create_archive(
        self, **kwargs: Unpack[CreateArchiveRequestTypeDef]
    ) -> CreateArchiveResponseTypeDef:
        """
        Creates a new email archive resource for storing and retaining emails.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_archive.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_archive)
        """

    def create_ingress_point(
        self, **kwargs: Unpack[CreateIngressPointRequestTypeDef]
    ) -> CreateIngressPointResponseTypeDef:
        """
        Provision a new ingress endpoint resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_ingress_point.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_ingress_point)
        """

    def create_relay(
        self, **kwargs: Unpack[CreateRelayRequestTypeDef]
    ) -> CreateRelayResponseTypeDef:
        """
        Creates a relay resource which can be used in rules to relay incoming emails to
        defined relay destinations.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_relay.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_relay)
        """

    def create_rule_set(
        self, **kwargs: Unpack[CreateRuleSetRequestTypeDef]
    ) -> CreateRuleSetResponseTypeDef:
        """
        Provision a new rule set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_rule_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_rule_set)
        """

    def create_traffic_policy(
        self, **kwargs: Unpack[CreateTrafficPolicyRequestTypeDef]
    ) -> CreateTrafficPolicyResponseTypeDef:
        """
        Provision a new traffic policy resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/create_traffic_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#create_traffic_policy)
        """

    def delete_addon_instance(
        self, **kwargs: Unpack[DeleteAddonInstanceRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Deletes an Add On instance.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/delete_addon_instance.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#delete_addon_instance)
        """

    def delete_addon_subscription(
        self, **kwargs: Unpack[DeleteAddonSubscriptionRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Deletes an Add On subscription.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/delete_addon_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#delete_addon_subscription)
        """

    def delete_address_list(
        self, **kwargs: Unpack[DeleteAddressListRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Deletes an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/delete_address_list.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#delete_address_list)
        """

    def delete_archive(self, **kwargs: Unpack[DeleteArchiveRequestTypeDef]) -> dict[str, Any]:
        """
        Initiates deletion of an email archive.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/delete_archive.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#delete_archive)
        """

    def delete_ingress_point(
        self, **kwargs: Unpack[DeleteIngressPointRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Delete an ingress endpoint resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/delete_ingress_point.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#delete_ingress_point)
        """

    def delete_relay(self, **kwargs: Unpack[DeleteRelayRequestTypeDef]) -> dict[str, Any]:
        """
        Deletes an existing relay resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/delete_relay.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#delete_relay)
        """

    def delete_rule_set(self, **kwargs: Unpack[DeleteRuleSetRequestTypeDef]) -> dict[str, Any]:
        """
        Delete a rule set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/delete_rule_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#delete_rule_set)
        """

    def delete_traffic_policy(
        self, **kwargs: Unpack[DeleteTrafficPolicyRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Delete a traffic policy resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/delete_traffic_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#delete_traffic_policy)
        """

    def deregister_member_from_address_list(
        self, **kwargs: Unpack[DeregisterMemberFromAddressListRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Removes a member from an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/deregister_member_from_address_list.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#deregister_member_from_address_list)
        """

    def get_addon_instance(
        self, **kwargs: Unpack[GetAddonInstanceRequestTypeDef]
    ) -> GetAddonInstanceResponseTypeDef:
        """
        Gets detailed information about an Add On instance.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_addon_instance.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_addon_instance)
        """

    def get_addon_subscription(
        self, **kwargs: Unpack[GetAddonSubscriptionRequestTypeDef]
    ) -> GetAddonSubscriptionResponseTypeDef:
        """
        Gets detailed information about an Add On subscription.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_addon_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_addon_subscription)
        """

    def get_address_list(
        self, **kwargs: Unpack[GetAddressListRequestTypeDef]
    ) -> GetAddressListResponseTypeDef:
        """
        Fetch attributes of an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_address_list.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_address_list)
        """

    def get_address_list_import_job(
        self, **kwargs: Unpack[GetAddressListImportJobRequestTypeDef]
    ) -> GetAddressListImportJobResponseTypeDef:
        """
        Fetch attributes of an import job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_address_list_import_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_address_list_import_job)
        """

    def get_archive(self, **kwargs: Unpack[GetArchiveRequestTypeDef]) -> GetArchiveResponseTypeDef:
        """
        Retrieves the full details and current state of a specified email archive.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_archive.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_archive)
        """

    def get_archive_export(
        self, **kwargs: Unpack[GetArchiveExportRequestTypeDef]
    ) -> GetArchiveExportResponseTypeDef:
        """
        Retrieves the details and current status of a specific email archive export job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_archive_export.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_archive_export)
        """

    def get_archive_message(
        self, **kwargs: Unpack[GetArchiveMessageRequestTypeDef]
    ) -> GetArchiveMessageResponseTypeDef:
        """
        Returns a pre-signed URL that provides temporary download access to the
        specific email message stored in the archive.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_archive_message.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_archive_message)
        """

    def get_archive_message_content(
        self, **kwargs: Unpack[GetArchiveMessageContentRequestTypeDef]
    ) -> GetArchiveMessageContentResponseTypeDef:
        """
        Returns the textual content of a specific email message stored in the archive.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_archive_message_content.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_archive_message_content)
        """

    def get_archive_search(
        self, **kwargs: Unpack[GetArchiveSearchRequestTypeDef]
    ) -> GetArchiveSearchResponseTypeDef:
        """
        Retrieves the details and current status of a specific email archive search job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_archive_search.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_archive_search)
        """

    def get_archive_search_results(
        self, **kwargs: Unpack[GetArchiveSearchResultsRequestTypeDef]
    ) -> GetArchiveSearchResultsResponseTypeDef:
        """
        Returns the results of a completed email archive search job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_archive_search_results.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_archive_search_results)
        """

    def get_ingress_point(
        self, **kwargs: Unpack[GetIngressPointRequestTypeDef]
    ) -> GetIngressPointResponseTypeDef:
        """
        Fetch ingress endpoint resource attributes.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_ingress_point.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_ingress_point)
        """

    def get_member_of_address_list(
        self, **kwargs: Unpack[GetMemberOfAddressListRequestTypeDef]
    ) -> GetMemberOfAddressListResponseTypeDef:
        """
        Fetch attributes of a member in an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_member_of_address_list.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_member_of_address_list)
        """

    def get_relay(self, **kwargs: Unpack[GetRelayRequestTypeDef]) -> GetRelayResponseTypeDef:
        """
        Fetch the relay resource and it's attributes.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_relay.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_relay)
        """

    def get_rule_set(self, **kwargs: Unpack[GetRuleSetRequestTypeDef]) -> GetRuleSetResponseTypeDef:
        """
        Fetch attributes of a rule set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_rule_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_rule_set)
        """

    def get_traffic_policy(
        self, **kwargs: Unpack[GetTrafficPolicyRequestTypeDef]
    ) -> GetTrafficPolicyResponseTypeDef:
        """
        Fetch attributes of a traffic policy resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_traffic_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_traffic_policy)
        """

    def list_addon_instances(
        self, **kwargs: Unpack[ListAddonInstancesRequestTypeDef]
    ) -> ListAddonInstancesResponseTypeDef:
        """
        Lists all Add On instances in your account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_addon_instances.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_addon_instances)
        """

    def list_addon_subscriptions(
        self, **kwargs: Unpack[ListAddonSubscriptionsRequestTypeDef]
    ) -> ListAddonSubscriptionsResponseTypeDef:
        """
        Lists all Add On subscriptions in your account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_addon_subscriptions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_addon_subscriptions)
        """

    def list_address_list_import_jobs(
        self, **kwargs: Unpack[ListAddressListImportJobsRequestTypeDef]
    ) -> ListAddressListImportJobsResponseTypeDef:
        """
        Lists jobs for an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_address_list_import_jobs.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_address_list_import_jobs)
        """

    def list_address_lists(
        self, **kwargs: Unpack[ListAddressListsRequestTypeDef]
    ) -> ListAddressListsResponseTypeDef:
        """
        Lists address lists for this account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_address_lists.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_address_lists)
        """

    def list_archive_exports(
        self, **kwargs: Unpack[ListArchiveExportsRequestTypeDef]
    ) -> ListArchiveExportsResponseTypeDef:
        """
        Returns a list of email archive export jobs.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_archive_exports.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_archive_exports)
        """

    def list_archive_searches(
        self, **kwargs: Unpack[ListArchiveSearchesRequestTypeDef]
    ) -> ListArchiveSearchesResponseTypeDef:
        """
        Returns a list of email archive search jobs.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_archive_searches.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_archive_searches)
        """

    def list_archives(
        self, **kwargs: Unpack[ListArchivesRequestTypeDef]
    ) -> ListArchivesResponseTypeDef:
        """
        Returns a list of all email archives in your account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_archives.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_archives)
        """

    def list_ingress_points(
        self, **kwargs: Unpack[ListIngressPointsRequestTypeDef]
    ) -> ListIngressPointsResponseTypeDef:
        """
        List all ingress endpoint resources.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_ingress_points.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_ingress_points)
        """

    def list_members_of_address_list(
        self, **kwargs: Unpack[ListMembersOfAddressListRequestTypeDef]
    ) -> ListMembersOfAddressListResponseTypeDef:
        """
        Lists members of an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_members_of_address_list.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_members_of_address_list)
        """

    def list_relays(self, **kwargs: Unpack[ListRelaysRequestTypeDef]) -> ListRelaysResponseTypeDef:
        """
        Lists all the existing relay resources.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_relays.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_relays)
        """

    def list_rule_sets(
        self, **kwargs: Unpack[ListRuleSetsRequestTypeDef]
    ) -> ListRuleSetsResponseTypeDef:
        """
        List rule sets for this account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_rule_sets.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_rule_sets)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceRequestTypeDef]
    ) -> ListTagsForResourceResponseTypeDef:
        """
        Retrieves the list of tags (keys and values) assigned to the resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_tags_for_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_tags_for_resource)
        """

    def list_traffic_policies(
        self, **kwargs: Unpack[ListTrafficPoliciesRequestTypeDef]
    ) -> ListTrafficPoliciesResponseTypeDef:
        """
        List traffic policy resources.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/list_traffic_policies.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#list_traffic_policies)
        """

    def register_member_to_address_list(
        self, **kwargs: Unpack[RegisterMemberToAddressListRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Adds a member to an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/register_member_to_address_list.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#register_member_to_address_list)
        """

    def start_address_list_import_job(
        self, **kwargs: Unpack[StartAddressListImportJobRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Starts an import job for an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/start_address_list_import_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#start_address_list_import_job)
        """

    def start_archive_export(
        self, **kwargs: Unpack[StartArchiveExportRequestTypeDef]
    ) -> StartArchiveExportResponseTypeDef:
        """
        Initiates an export of emails from the specified archive.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/start_archive_export.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#start_archive_export)
        """

    def start_archive_search(
        self, **kwargs: Unpack[StartArchiveSearchRequestTypeDef]
    ) -> StartArchiveSearchResponseTypeDef:
        """
        Initiates a search across emails in the specified archive.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/start_archive_search.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#start_archive_search)
        """

    def stop_address_list_import_job(
        self, **kwargs: Unpack[StopAddressListImportJobRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Stops an ongoing import job for an address list.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/stop_address_list_import_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#stop_address_list_import_job)
        """

    def stop_archive_export(
        self, **kwargs: Unpack[StopArchiveExportRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Stops an in-progress export of emails from an archive.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/stop_archive_export.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#stop_archive_export)
        """

    def stop_archive_search(
        self, **kwargs: Unpack[StopArchiveSearchRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Stops an in-progress archive search job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/stop_archive_search.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#stop_archive_search)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceRequestTypeDef]) -> dict[str, Any]:
        """
        Adds one or more tags (keys and values) to a specified resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/tag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceRequestTypeDef]) -> dict[str, Any]:
        """
        Remove one or more tags (keys and values) from a specified resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/untag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#untag_resource)
        """

    def update_archive(self, **kwargs: Unpack[UpdateArchiveRequestTypeDef]) -> dict[str, Any]:
        """
        Updates the attributes of an existing email archive.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/update_archive.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#update_archive)
        """

    def update_ingress_point(
        self, **kwargs: Unpack[UpdateIngressPointRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Update attributes of a provisioned ingress endpoint resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/update_ingress_point.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#update_ingress_point)
        """

    def update_relay(self, **kwargs: Unpack[UpdateRelayRequestTypeDef]) -> dict[str, Any]:
        """
        Updates the attributes of an existing relay resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/update_relay.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#update_relay)
        """

    def update_rule_set(self, **kwargs: Unpack[UpdateRuleSetRequestTypeDef]) -> dict[str, Any]:
        """
        Update attributes of an already provisioned rule set.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/update_rule_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#update_rule_set)
        """

    def update_traffic_policy(
        self, **kwargs: Unpack[UpdateTrafficPolicyRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Update attributes of an already provisioned traffic policy resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/update_traffic_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#update_traffic_policy)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_addon_instances"]
    ) -> ListAddonInstancesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_addon_subscriptions"]
    ) -> ListAddonSubscriptionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_address_list_import_jobs"]
    ) -> ListAddressListImportJobsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_address_lists"]
    ) -> ListAddressListsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_archive_exports"]
    ) -> ListArchiveExportsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_archive_searches"]
    ) -> ListArchiveSearchesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_archives"]
    ) -> ListArchivesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_ingress_points"]
    ) -> ListIngressPointsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_members_of_address_list"]
    ) -> ListMembersOfAddressListPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_relays"]
    ) -> ListRelaysPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_rule_sets"]
    ) -> ListRuleSetsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_traffic_policies"]
    ) -> ListTrafficPoliciesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/client/#get_paginator)
        """



"""
Main interface for mailmanager service.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_mailmanager import (
        Client,
        ListAddonInstancesPaginator,
        ListAddonSubscriptionsPaginator,
        ListAddressListImportJobsPaginator,
        ListAddressListsPaginator,
        ListArchiveExportsPaginator,
        ListArchiveSearchesPaginator,
        ListArchivesPaginator,
        ListIngressPointsPaginator,
        ListMembersOfAddressListPaginator,
        ListRelaysPaginator,
        ListRuleSetsPaginator,
        ListTrafficPoliciesPaginator,
        MailManagerClient,
    )

    session = Session()
    client: MailManagerClient = session.client("mailmanager")

    list_addon_instances_paginator: ListAddonInstancesPaginator = client.get_paginator("list_addon_instances")
    list_addon_subscriptions_paginator: ListAddonSubscriptionsPaginator = client.get_paginator("list_addon_subscriptions")
    list_address_list_import_jobs_paginator: ListAddressListImportJobsPaginator = client.get_paginator("list_address_list_import_jobs")
    list_address_lists_paginator: ListAddressListsPaginator = client.get_paginator("list_address_lists")
    list_archive_exports_paginator: ListArchiveExportsPaginator = client.get_paginator("list_archive_exports")
    list_archive_searches_paginator: ListArchiveSearchesPaginator = client.get_paginator("list_archive_searches")
    list_archives_paginator: ListArchivesPaginator = client.get_paginator("list_archives")
    list_ingress_points_paginator: ListIngressPointsPaginator = client.get_paginator("list_ingress_points")
    list_members_of_address_list_paginator: ListMembersOfAddressListPaginator = client.get_paginator("list_members_of_address_list")
    list_relays_paginator: ListRelaysPaginator = client.get_paginator("list_relays")
    list_rule_sets_paginator: ListRuleSetsPaginator = client.get_paginator("list_rule_sets")
    list_traffic_policies_paginator: ListTrafficPoliciesPaginator = client.get_paginator("list_traffic_policies")
    ```
"""

from .client import MailManagerClient
from .paginator import (
    ListAddonInstancesPaginator,
    ListAddonSubscriptionsPaginator,
    ListAddressListImportJobsPaginator,
    ListAddressListsPaginator,
    ListArchiveExportsPaginator,
    ListArchiveSearchesPaginator,
    ListArchivesPaginator,
    ListIngressPointsPaginator,
    ListMembersOfAddressListPaginator,
    ListRelaysPaginator,
    ListRuleSetsPaginator,
    ListTrafficPoliciesPaginator,
)

Client = MailManagerClient

__all__ = (
    "Client",
    "ListAddonInstancesPaginator",
    "ListAddonSubscriptionsPaginator",
    "ListAddressListImportJobsPaginator",
    "ListAddressListsPaginator",
    "ListArchiveExportsPaginator",
    "ListArchiveSearchesPaginator",
    "ListArchivesPaginator",
    "ListIngressPointsPaginator",
    "ListMembersOfAddressListPaginator",
    "ListRelaysPaginator",
    "ListRuleSetsPaginator",
    "ListTrafficPoliciesPaginator",
    "MailManagerClient",
)



"""
Type annotations for mailmanager service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_mailmanager.client import MailManagerClient
    from types_boto3_mailmanager.paginator import (
        ListAddonInstancesPaginator,
        ListAddonSubscriptionsPaginator,
        ListAddressListImportJobsPaginator,
        ListAddressListsPaginator,
        ListArchiveExportsPaginator,
        ListArchiveSearchesPaginator,
        ListArchivesPaginator,
        ListIngressPointsPaginator,
        ListMembersOfAddressListPaginator,
        ListRelaysPaginator,
        ListRuleSetsPaginator,
        ListTrafficPoliciesPaginator,
    )

    session = Session()
    client: MailManagerClient = session.client("mailmanager")

    list_addon_instances_paginator: ListAddonInstancesPaginator = client.get_paginator("list_addon_instances")
    list_addon_subscriptions_paginator: ListAddonSubscriptionsPaginator = client.get_paginator("list_addon_subscriptions")
    list_address_list_import_jobs_paginator: ListAddressListImportJobsPaginator = client.get_paginator("list_address_list_import_jobs")
    list_address_lists_paginator: ListAddressListsPaginator = client.get_paginator("list_address_lists")
    list_archive_exports_paginator: ListArchiveExportsPaginator = client.get_paginator("list_archive_exports")
    list_archive_searches_paginator: ListArchiveSearchesPaginator = client.get_paginator("list_archive_searches")
    list_archives_paginator: ListArchivesPaginator = client.get_paginator("list_archives")
    list_ingress_points_paginator: ListIngressPointsPaginator = client.get_paginator("list_ingress_points")
    list_members_of_address_list_paginator: ListMembersOfAddressListPaginator = client.get_paginator("list_members_of_address_list")
    list_relays_paginator: ListRelaysPaginator = client.get_paginator("list_relays")
    list_rule_sets_paginator: ListRuleSetsPaginator = client.get_paginator("list_rule_sets")
    list_traffic_policies_paginator: ListTrafficPoliciesPaginator = client.get_paginator("list_traffic_policies")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListAddonInstancesRequestPaginateTypeDef,
    ListAddonInstancesResponseTypeDef,
    ListAddonSubscriptionsRequestPaginateTypeDef,
    ListAddonSubscriptionsResponseTypeDef,
    ListAddressListImportJobsRequestPaginateTypeDef,
    ListAddressListImportJobsResponseTypeDef,
    ListAddressListsRequestPaginateTypeDef,
    ListAddressListsResponseTypeDef,
    ListArchiveExportsRequestPaginateTypeDef,
    ListArchiveExportsResponseTypeDef,
    ListArchiveSearchesRequestPaginateTypeDef,
    ListArchiveSearchesResponseTypeDef,
    ListArchivesRequestPaginateTypeDef,
    ListArchivesResponseTypeDef,
    ListIngressPointsRequestPaginateTypeDef,
    ListIngressPointsResponseTypeDef,
    ListMembersOfAddressListRequestPaginateTypeDef,
    ListMembersOfAddressListResponseTypeDef,
    ListRelaysRequestPaginateTypeDef,
    ListRelaysResponseTypeDef,
    ListRuleSetsRequestPaginateTypeDef,
    ListRuleSetsResponseTypeDef,
    ListTrafficPoliciesRequestPaginateTypeDef,
    ListTrafficPoliciesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListAddonInstancesPaginator",
    "ListAddonSubscriptionsPaginator",
    "ListAddressListImportJobsPaginator",
    "ListAddressListsPaginator",
    "ListArchiveExportsPaginator",
    "ListArchiveSearchesPaginator",
    "ListArchivesPaginator",
    "ListIngressPointsPaginator",
    "ListMembersOfAddressListPaginator",
    "ListRelaysPaginator",
    "ListRuleSetsPaginator",
    "ListTrafficPoliciesPaginator",
)


if TYPE_CHECKING:
    _ListAddonInstancesPaginatorBase = Paginator[ListAddonInstancesResponseTypeDef]
else:
    _ListAddonInstancesPaginatorBase = Paginator  # type: ignore[assignment]


class ListAddonInstancesPaginator(_ListAddonInstancesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListAddonInstances.html#MailManager.Paginator.ListAddonInstances)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listaddoninstancespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAddonInstancesRequestPaginateTypeDef]
    ) -> PageIterator[ListAddonInstancesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListAddonInstances.html#MailManager.Paginator.ListAddonInstances.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listaddoninstancespaginator)
        """


if TYPE_CHECKING:
    _ListAddonSubscriptionsPaginatorBase = Paginator[ListAddonSubscriptionsResponseTypeDef]
else:
    _ListAddonSubscriptionsPaginatorBase = Paginator  # type: ignore[assignment]


class ListAddonSubscriptionsPaginator(_ListAddonSubscriptionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListAddonSubscriptions.html#MailManager.Paginator.ListAddonSubscriptions)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listaddonsubscriptionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAddonSubscriptionsRequestPaginateTypeDef]
    ) -> PageIterator[ListAddonSubscriptionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListAddonSubscriptions.html#MailManager.Paginator.ListAddonSubscriptions.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listaddonsubscriptionspaginator)
        """


if TYPE_CHECKING:
    _ListAddressListImportJobsPaginatorBase = Paginator[ListAddressListImportJobsResponseTypeDef]
else:
    _ListAddressListImportJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListAddressListImportJobsPaginator(_ListAddressListImportJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListAddressListImportJobs.html#MailManager.Paginator.ListAddressListImportJobs)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listaddresslistimportjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAddressListImportJobsRequestPaginateTypeDef]
    ) -> PageIterator[ListAddressListImportJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListAddressListImportJobs.html#MailManager.Paginator.ListAddressListImportJobs.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listaddresslistimportjobspaginator)
        """


if TYPE_CHECKING:
    _ListAddressListsPaginatorBase = Paginator[ListAddressListsResponseTypeDef]
else:
    _ListAddressListsPaginatorBase = Paginator  # type: ignore[assignment]


class ListAddressListsPaginator(_ListAddressListsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListAddressLists.html#MailManager.Paginator.ListAddressLists)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listaddresslistspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAddressListsRequestPaginateTypeDef]
    ) -> PageIterator[ListAddressListsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListAddressLists.html#MailManager.Paginator.ListAddressLists.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listaddresslistspaginator)
        """


if TYPE_CHECKING:
    _ListArchiveExportsPaginatorBase = Paginator[ListArchiveExportsResponseTypeDef]
else:
    _ListArchiveExportsPaginatorBase = Paginator  # type: ignore[assignment]


class ListArchiveExportsPaginator(_ListArchiveExportsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListArchiveExports.html#MailManager.Paginator.ListArchiveExports)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listarchiveexportspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListArchiveExportsRequestPaginateTypeDef]
    ) -> PageIterator[ListArchiveExportsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListArchiveExports.html#MailManager.Paginator.ListArchiveExports.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listarchiveexportspaginator)
        """


if TYPE_CHECKING:
    _ListArchiveSearchesPaginatorBase = Paginator[ListArchiveSearchesResponseTypeDef]
else:
    _ListArchiveSearchesPaginatorBase = Paginator  # type: ignore[assignment]


class ListArchiveSearchesPaginator(_ListArchiveSearchesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListArchiveSearches.html#MailManager.Paginator.ListArchiveSearches)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listarchivesearchespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListArchiveSearchesRequestPaginateTypeDef]
    ) -> PageIterator[ListArchiveSearchesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListArchiveSearches.html#MailManager.Paginator.ListArchiveSearches.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listarchivesearchespaginator)
        """


if TYPE_CHECKING:
    _ListArchivesPaginatorBase = Paginator[ListArchivesResponseTypeDef]
else:
    _ListArchivesPaginatorBase = Paginator  # type: ignore[assignment]


class ListArchivesPaginator(_ListArchivesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListArchives.html#MailManager.Paginator.ListArchives)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listarchivespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListArchivesRequestPaginateTypeDef]
    ) -> PageIterator[ListArchivesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListArchives.html#MailManager.Paginator.ListArchives.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listarchivespaginator)
        """


if TYPE_CHECKING:
    _ListIngressPointsPaginatorBase = Paginator[ListIngressPointsResponseTypeDef]
else:
    _ListIngressPointsPaginatorBase = Paginator  # type: ignore[assignment]


class ListIngressPointsPaginator(_ListIngressPointsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListIngressPoints.html#MailManager.Paginator.ListIngressPoints)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listingresspointspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListIngressPointsRequestPaginateTypeDef]
    ) -> PageIterator[ListIngressPointsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListIngressPoints.html#MailManager.Paginator.ListIngressPoints.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listingresspointspaginator)
        """


if TYPE_CHECKING:
    _ListMembersOfAddressListPaginatorBase = Paginator[ListMembersOfAddressListResponseTypeDef]
else:
    _ListMembersOfAddressListPaginatorBase = Paginator  # type: ignore[assignment]


class ListMembersOfAddressListPaginator(_ListMembersOfAddressListPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListMembersOfAddressList.html#MailManager.Paginator.ListMembersOfAddressList)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listmembersofaddresslistpaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListMembersOfAddressListRequestPaginateTypeDef]
    ) -> PageIterator[ListMembersOfAddressListResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListMembersOfAddressList.html#MailManager.Paginator.ListMembersOfAddressList.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listmembersofaddresslistpaginator)
        """


if TYPE_CHECKING:
    _ListRelaysPaginatorBase = Paginator[ListRelaysResponseTypeDef]
else:
    _ListRelaysPaginatorBase = Paginator  # type: ignore[assignment]


class ListRelaysPaginator(_ListRelaysPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListRelays.html#MailManager.Paginator.ListRelays)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listrelayspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListRelaysRequestPaginateTypeDef]
    ) -> PageIterator[ListRelaysResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListRelays.html#MailManager.Paginator.ListRelays.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listrelayspaginator)
        """


if TYPE_CHECKING:
    _ListRuleSetsPaginatorBase = Paginator[ListRuleSetsResponseTypeDef]
else:
    _ListRuleSetsPaginatorBase = Paginator  # type: ignore[assignment]


class ListRuleSetsPaginator(_ListRuleSetsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListRuleSets.html#MailManager.Paginator.ListRuleSets)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listrulesetspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListRuleSetsRequestPaginateTypeDef]
    ) -> PageIterator[ListRuleSetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListRuleSets.html#MailManager.Paginator.ListRuleSets.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listrulesetspaginator)
        """


if TYPE_CHECKING:
    _ListTrafficPoliciesPaginatorBase = Paginator[ListTrafficPoliciesResponseTypeDef]
else:
    _ListTrafficPoliciesPaginatorBase = Paginator  # type: ignore[assignment]


class ListTrafficPoliciesPaginator(_ListTrafficPoliciesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListTrafficPolicies.html#MailManager.Paginator.ListTrafficPolicies)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listtrafficpoliciespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTrafficPoliciesRequestPaginateTypeDef]
    ) -> PageIterator[ListTrafficPoliciesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mailmanager/paginator/ListTrafficPolicies.html#MailManager.Paginator.ListTrafficPolicies.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mailmanager/paginators/#listtrafficpoliciespaginator)
        """
